@@ -269,7 +269,7 @@ def json_logic_replace_data(rule, data, string_data=None, json_data=None):
         str_json_data = json.dumps(json_data)
         for key, val in res_dct.items():
             str_json_data = str_json_data.replace(key, str(val))
-        json_data = json.loads(str_json_data)
+        json_data = json.loads(str_json_data, strict=False)
         return json_data
 
 
@@ -289,6 +289,8 @@ def run_external_workflow(conf, task_id, vtiger_access):
 
         if task_id in conf.get('external_workflow_config', ''):
             external_workflow_config = conf.get('external_workflow_config').get(task_id, '')
+        else:
+            external_workflow_config = {}
 
         if external_workflow_config:
 
@@ -511,6 +513,8 @@ def invoke_set_value_task(conf, task_id, vtiger_access, record_id=None):
 
         if task_id in conf.get('set_value_configs', ''):
             set_value_configs = conf.get('set_value_configs').get(task_id, '')
+        else:
+            set_value_configs = {}
 
         if set_value_configs:
             set_value_fields = set_value_configs.get('set_value_fields', '')
@@ -585,13 +589,11 @@ def invoke_set_value_task(conf, task_id, vtiger_access, record_id=None):
 
                                 # retry to execute query
 
-
                                 url = '{vtiger_url}/webservice.php?operation=query&sessionName={sessionName}&query={query}'.format(
                                     sessionName=session_name, query=query, vtiger_url=vtiger_access.get('vtiger_url'))
                                 url = url.replace("''", "' '")
                                 response, status = invoke_http_request(url, request_type, headers)
 
-
                                 vtiger_access['vtiger_session'] = session_name
                                 Variable.update(key='vtiger_access', value=vtiger_access, serialize_json=True)
 
@@ -634,6 +636,8 @@ def invoke_web_service_task(conf, task_id, response_type="json"):
 
         if task_id in conf.get('web_service_configs', ''):
             web_service_configs = conf.get('web_service_configs').get(task_id, '')
+        else:
+            web_service_configs = {}
 
         if web_service_configs:
 
@@ -682,6 +686,8 @@ def invoke_provider_manager_task(conf, task_id):
 
         if task_id in conf.get('provider_manager_config', ''):
             provider_manager_config = conf.get('provider_manager_config').get(task_id, '')
+        else:
+            provider_manager_config = {}
 
         if provider_manager_config:
 
@@ -724,6 +730,8 @@ def invoke_conditional_task(conf, task_id, true_task, false_task):
 
         if task_id in conf.get('conditions', ''):
             condition = conf.get('conditions').get(task_id, '')
+        else:
+            condition = {}
 
         if condition:
 
@@ -787,6 +795,8 @@ def add_delay_task(conf, task_id, vtiger_access):
             "conf": conf,
             "delay_task_configs": delay_task_configs
         }
+    else:
+        payload = {}
 
     endpoint = '{service_url}/api/v1/add-delayed-data'.format(service_url=vtiger_access.get('service_url'))
     headers = {'content_type': 'application/json', 'Authorization': vtiger_access.get('api_access_key')}
@@ -865,7 +875,7 @@ def get_record_details_from_crm(vtiger_access, data):
         user_id_list = []
 
         for element in data:
-            id = element.get('id', '')
+            id = str(element.get('id', ''))
             if id:
                 # prepare query id using source module
                 record_id = id if "x" in id else "{module}x{record_id}".format(module=module_id, record_id=id)
